@@ -3,7 +3,7 @@
 #include <iostream>
 #endif
 #include "pointls.h"
-//#include "myutils.h"
+#define R_NO_REMAP
 #include "R.h" // pour Rprintf
 
 Cpointls::Cpointls(Cpointls& ptls) {
